@@ -1643,9 +1643,10 @@ class GeoArray(object):
             if not (self.footprint_poly.within(self.box.mapPoly) or self.footprint_poly.equals(self.box.mapPoly)):
                 self.footprint_poly = self.footprint_poly.intersection(self.box.mapPoly)
 
-    def read_pointData(self, mapXY_points, mapXY_points_prj=None, band=None):
+    def read_pointData(self, mapXY_points, mapXY_points_prj=None, band=None, offside_val=np.nan):
         """Returns the array values for the given set of X/Y coordinates.
-         NOTE: If GeoArray has been instanced with a file path, the function will read the dataset into memory.
+
+        NOTE: If GeoArray has been instanced with a file path, the function will read the dataset into memory.
 
         :param mapXY_points:        <np.ndarray, tuple> X/Y coordinates of the points of interest. If a numpy array is
                                     given, it must have the shape [Nx2]
@@ -1653,7 +1654,11 @@ class GeoArray(object):
                                     coordinates.
         :param band:                <int> the band index of the band of interest. If None, the values of all bands are
                                     returned.
-        :return:                    np.ndarray with shape [Nx2xbands]
+        :param offside_val:         fill value in case input coordinates are geographically outside of the GeoArray
+                                    instance
+        :return:                    - int in case only a singe coordinate is passed
+                                    - np.ndarray with shape [Nx1] in case only one band is requested
+                                    - np.ndarray with shape [Nx1xbands] in case all bands are requested
         """
 
         mapXY = mapXY_points if isinstance(mapXY_points, np.ndarray) else np.array(mapXY_points).reshape(1, 2)
@@ -1661,16 +1666,44 @@ class GeoArray(object):
 
         assert prj, 'A projection is needed for returning image DNs at specific map X/Y coordinates!'
         if not prj_equal(prj1=prj, prj2=self.prj):
-            mapXY = transform_any_prj(prj, self.prj, mapXY[:, 0], mapXY[:, 1])
+            mapX, mapY = transform_any_prj(prj, self.prj, mapXY[:, 0], mapXY[:, 1])
+            mapXY = np.hstack([mapX.reshape(-1, 1),
+                               mapY.reshape(-1, 1)])
 
         imXY = mapXY2imXY(mapXY, self.geotransform)
+
+        # get a mask of all map positions geographically outside of the GeoArray instance
+        mask_off = (np.any(imXY < 0, axis=1)) |\
+                   (imXY[:, 0] >= self.columns) |\
+                   (imXY[:, 1] >= self.rows)
+
         imYX = np.fliplr(np.array(imXY)).astype(np.int16)
 
         if imYX.size == 2:  # only one coordinate pair
             Y, X = imYX[0].tolist()
-            return self[Y, X, band]
+
+            if X < 0 or X >= self.columns or Y < 0 or Y >= self.rows:
+                pointdata = offside_val
+            else:
+                pointdata = self[Y, X, band]
+
         else:  # multiple coordinate pairs
-            return self[tuple(imYX.T.tolist() + [band])]
+            if True in mask_off:
+                shape_exp = (imXY.shape[0], 1, self.bands) if band is None else (imXY.shape[0], 1)
+                pointdata = np.full(shape_exp, offside_val)
+                imYX = imYX[~mask_off, :]
+
+                if band is None:
+                    pointdata[~mask_off, 0, :] = \
+                        self[tuple(imYX.T.tolist() + [band])] \
+                        .reshape(imYX.shape[0], self.bands)
+                else:
+                    pointdata[~mask_off, 0] = \
+                        self[tuple(imYX.T.tolist() + [band])]
+            else:
+                pointdata = self[tuple(imYX.T.tolist() + [band])]
+
+        return pointdata
 
     def to_mem(self):
         """Reads the whole dataset into memory and sets self.arr to the read data."""
